pub struct VMMemoryRegion {
pub gpa: GuestPhysAddr,
pub hva: HostVirtAddr,
pub layout: Layout,
pub needs_dealloc: bool,
}Expand description
Represents a memory region in a virtual machine.
Fields
gpa: GuestPhysAddrGuest physical address.
hva: HostVirtAddrHost virtual address.
layout: LayoutMemory layout of the region.
needs_dealloc: boolWhether this region was allocated by the allocator and needs to be deallocated
Implementations
Sourceimpl VMMemoryRegion
impl VMMemoryRegion
Sourcepub fn host_paddr(&self) -> HostPhysAddr
pub fn host_paddr(&self) -> HostPhysAddr
Returns the host physical address backing this guest memory region.
Sourcepub fn is_identical(&self) -> bool
pub fn is_identical(&self) -> bool
Returns true if the guest physical address is identical to the host physical address.